/*
 * Copyright (C) 1994-2018 Altair Engineering, Inc.
 * For more information, contact Altair at www.altair.com.
 *
 * This file is part of the PBS Professional ("PBS Pro") software.
 *
 * Open Source License Information:
 *
 * PBS Pro is free software. You can redistribute it and/or modify it under the
 * terms of the GNU Affero General Public License as published by the Free
 * Software Foundation, either version 3 of the License, or (at your option) any
 * later version.
 *
 * PBS Pro is distributed in the hope that it will be useful, but WITHOUT ANY
 * WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
 * FOR A PARTICULAR PURPOSE.
 * See the GNU Affero General Public License for more details.
 *
 * You should have received a copy of the GNU Affero General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 *
 * Commercial License Information:
 *
 * For a copy of the commercial license terms and conditions,
 * go to: (http://www.pbspro.com/UserArea/agreement.html)
 * or contact the Altair Legal Department.
 *
 * Altair’s dual-license business model allows companies, individuals, and
 * organizations to create proprietary derivative works of PBS Pro and
 * distribute them - whether embedded or bundled with other software -
 * under a commercial license agreement.
 *
 * Use of Altair’s trademarks, including but not limited to "PBS™",
 * "PBS Professional®", and "PBS Pro™" and Altair’s logos is subject to Altair's
 * trademark licensing policies.
 *
 */
/**
 * @file	replace.c
 * @brief
 * This file contains homebrewed PBS replacements for
 * library functions found on BSD 4.4-Lite.
 *
 */

#include <pbs_config.h>   /* the master config generated by configure */

#include <errno.h>
#include <stdio.h>
#include <stdarg.h>
#include <stdlib.h>


extern char *credb;

/**
 * @brief
 *	accepts varargs as error inputs and logs error on stderr.
 *
 * @param[in] fmt - error msg
 *
 */
void
errx(int err, const char *fmt, ...)
{
	va_list ap;

	va_start(ap, fmt);
	(void)vfprintf(stderr, fmt, ap);
	exit(err);
}

/**
 * @brief
 *      accepts varargs as warning inputs and logs the same on stderr.
 *
 * @param[in] fmt - error msg
 *
 */
void
warnx(const char *fmt, ...)
{
	va_list ap;

	va_start(ap, fmt);
	(void)vfprintf(stderr, fmt, ap);
}

/**
 * @brief
 *	print the error number and message to stderr.
 * @par Note:	frees the credentials.
 *
 * @param[in] val - error val
 * @param[in] str - error msg
 *
 * @return	Void
 *
 */
void
err(int val, char *str)
{
	if (str)
		(void)fprintf(stderr, "%s\n", str);

	if (credb != NULL) {
		(void)free(credb);
		credb = NULL;
	}

	exit(val);
}
